/*
 *    Copyright 2008-2010 Simone Tripodi
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */
package com.googlecode.injectlet.core.annotations;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Annotated {@link AbstractGuiceServletContextListener} instances with
 * this annotation is useful to identify the {@link Injector} id into
 * the {@link ServletContextListener}.
 *
 * @author Simone Tripodi
 * @version $Id: InjectorId.java 447 2010-06-02 20:28:18Z simone.tripodi $
 * @since 1.2
 */
@Retention(RetentionPolicy.RUNTIME)
@Target({ ElementType.TYPE })
@Documented
public @interface InjectorId {

    /**
     * The {@link Injector} id.
     *
     * @return the {@link Injector} id.
     */
    String value();

}
