/*
 *    Copyright 2008-2010 Simone Tripodi
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */
package com.googlecode.injectlet.core.servlet;

import java.lang.annotation.Annotation;
import java.lang.reflect.Field;
import java.lang.reflect.Method;
import java.util.HashMap;
import java.util.Map;

import com.google.inject.Binder;

/**
 * 
 *
 * @author Simone Tripodi
 * @version $Id: AnnotationsClassVisitor.java 442 2010-06-02 20:09:12Z simone.tripodi $
 */
final class AnnotationsClassVisitor {

    private final Map<Class<? extends Annotation>, AnnotationHandler<? extends Annotation>> handlers = new HashMap<Class<? extends Annotation>, AnnotationHandler<? extends Annotation>>();

    public <A extends Annotation> void registerHandler(Class<A> annotationType, AnnotationHandler<A> handler) {
        this.handlers.put(annotationType, handler);
    }

    public void visit(Class<?> type, Binder binder) {
        if (Object.class == type) {
            return;
        }

        for (Field field : type.getDeclaredFields()) {
            for (Annotation annotation : field.getAnnotations()) {
                this.handle(binder, annotation);
            }
        }

        for (Method method : type.getDeclaredMethods()) {
            for (Annotation[] annotations : method.getParameterAnnotations()) {
                for (Annotation annotation : annotations) {
                    this.handle(binder, annotation);
                }
            }
        }

        this.visit(type.getSuperclass(), binder);
    }

    @SuppressWarnings("unchecked")
    private void handle(Binder binder, Annotation annotation) {
        AnnotationHandler<Annotation> handler = (AnnotationHandler<Annotation>) this.handlers.get(annotation.annotationType());
        if (handler != null) {
            handler.handle(binder, annotation);
        }
    }

}
