/*
 *    Copyright 2008-2010 Simone Tripodi
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */
package com.googlecode.injectlet.core.servlet;

import javax.servlet.FilterConfig;

import com.google.inject.Binder;
import com.googlecode.injectlet.core.annotations.FilterInitParam;

/**
 * 
 *
 * @author Simone Tripodi
 * @version $Id: FilterInitParamHandler.java 447 2010-06-02 20:28:18Z simone.tripodi $
 */
final class FilterInitParamHandler implements AnnotationHandler<FilterInitParam> {

    private final FilterConfig filterConfig;

    public FilterInitParamHandler(FilterConfig filterConfig) {
        this.filterConfig = filterConfig;
    }

    @Override
    public void handle(Binder binder, FilterInitParam annotation) {
        String initParam = this.filterConfig.getInitParameter(annotation.value());
        if (initParam == null) {
            return;
        }
        binder.bindConstant()
              .annotatedWith(annotation)
              .to(initParam);
    }

}
